@@ -1,6 +1,16 @@
+mod fmt;
+
 use quote::quote;
 use syn::__private::TokenStream2;
 use syn::{parse_macro_input, Data, DeriveInput, Fields};
+use crate::fmt::format;
+
+#[proc_macro]
+pub fn expr(input: proc_macro::TokenStream) -> proc_macro::TokenStream{
+    let input = TokenStream2::from(input);
+    let str_input = format(input.to_string());
+    proc_macro::TokenStream::from(quote! {::shoulda::core::specifics::panic::Expression::new(#input, #str_input.to_string())})
+}
 
 #[proc_macro_derive(Shoulda)]
 pub fn shoulda(input: proc_macro::TokenStream) -> proc_macro::TokenStream {
